@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 from os.path import join
 
+import html2text
+
 from django.conf import settings
 from django.template import Context, TemplateDoesNotExist
 from django.template.loader import select_template
@@ -33,7 +35,7 @@ class BaseMail(object):
 
         # Check that all the mandatory context is present.
         for key in self.get_params():
-            if not key in context:
+            if key not in context:
                 raise exceptions.MissingMailContextParamException(repr(key))
 
     def get_language(self):
@@ -97,22 +99,38 @@ class BaseMail(object):
         return rendered.strip()
 
     def create_email_msg(self, emails, attachments=None, from_email=None,
-                         lang=None, message_class=EmailMultiRelated):
+                         lang=None, message_class=EmailMultiRelated,
+                         headers=None):
         """Create an email message instance."""
 
         from_email = from_email or settings.DEFAULT_FROM_EMAIL
         subject = self._render_part('subject.txt', lang=lang).strip()
-        body = self._render_part('body.txt', lang=lang)
+        try:
+            body = self._render_part('body.txt', lang=lang)
+        except TemplateDoesNotExist:
+            body = None
         try:
             html_content = self._render_part('body.html', lang=lang)
         except TemplateDoesNotExist:
             html_content = None
 
-        msg = message_class(
-            subject, body, from_email, emails,
-            headers={'Reply-To': getattr(settings,
-                                         "SUPPORT_EMAIL",
-                                         settings.DEFAULT_FROM_EMAIL)})
+        # If we have neither a html or txt template
+        if html_content is None and body is None:
+            raise TemplateDoesNotExist(
+                "Txt and html templates have not been found")
+
+        # If we have the html template only, we build automatically
+        # txt content.
+        if html_content is not None and body is None:
+            h = html2text.HTML2Text()
+            body = h.handle(html_content)
+
+        if headers is None:
+            headers = {'Reply-To': getattr(settings,
+                                           "SUPPORT_EMAIL",
+                                           settings.DEFAULT_FROM_EMAIL)}
+
+        msg = message_class(subject, body, from_email, emails, headers=headers)
         if html_content:
             msg.attach_alternative(html_content, 'text/html')
 
@@ -127,10 +145,10 @@ class BaseMail(object):
                         msg.attach(filename, attachment.read(), mimetype)
         return msg
 
-    def send(self, emails, attachments=None, from_email=None):
+    def send(self, emails, attachments=None, from_email=None, headers=None):
         """Create the message and send it to emails."""
         message = self.create_email_msg(emails, attachments=attachments,
-                                        from_email=from_email)
+                                        from_email=from_email, headers=headers)
         message.send()
 
     def mail_admins(self, attachments=None, from_email=None):
